##  Overview
The integration between SAP LeanIX and ServiceNow is a powerful way to enable the transparent flow of data between the two systems. This documentation covers key information to help you understand the Integration more deeply:
  * Communication with ServiceNow.
  * The core concepts used to integrate.
  * The default supported configuration and best practices.
